pub enum PageKind {
Article,
Folder,
}Variants
Article
Markdown file, not a folder index.
Folder
Markdown file recognized as a folder index by
crate::home::is_home_file.
Implementations
Sourceimpl PageKind
impl PageKind
Sourcepub fn is_listable_at_depth_all(self) -> bool
pub fn is_listable_at_depth_all(self) -> bool
True when pages of this kind appear in children listings at
children_depth: all.
Sourcepub fn is_listable_at_depth_direct(self) -> bool
pub fn is_listable_at_depth_direct(self) -> bool
True when pages of this kind appear in children listings at
children_depth: direct.